@@ -1,5 +1,6 @@
 from .bedwars import Bedwars
 from .skywars import Skywars
+from .duels import Duels
 import datetime
 from .. import utils
 
@@ -49,12 +50,13 @@ class HypixelPlayer:
         self.social_media = SocialMedia(data)
         self.bedwars = Bedwars(data)
         self.skywars = Skywars(data)
+        self.duels = Duels(data)
 
 
 class LoginTimes:
     def __init__(self, data):
-        self.first = datetime.date.fromtimestamp(data.get("player", {}).get("firstLogin", 0) / 1000)
-        self.last = datetime.date.fromtimestamp(data.get("player", {}).get("lastLogin", 0) / 1000)
+        self.first = datetime.datetime.fromtimestamp(data.get("player", {}).get("firstLogin", 0) / 1000)
+        self.last = datetime.datetime.fromtimestamp(data.get("player", {}).get("lastLogin", 0) / 1000)
 
 
 class SocialMedia:
